import styled from '@emotion/styled'
import { PhoneCodeData } from '../data'
import type { FormEvent } from 'react'
import type { AccountProfileOptions, ExtendedProfile } from '../types'

interface Props {
  handleProfileChange: (event: FormEvent) => void
  newProfile: ExtendedProfile
  options: AccountProfileOptions
}

export const PhoneCodeInput: React.FC<Props> = ({
  handleProfileChange,
  newProfile,
  options: { fontLabel, readOnlyPhoneNumber }
}) => {
  return (
    <PhoneCodeContainer>
      <PhoneCode
        name='phoneCode'
        style={{ fontFamily: fontLabel }}
        onChange={(e) => handleProfileChange(e)}
        disabled={readOnlyPhoneNumber}
        value={newProfile.phoneCode}
      >
        {PhoneCodeData.map(({ dial_code, name, code }) => {
          const phoneCode = code + ' ' + dial_code
          const isSelected = phoneCode === newProfile.phoneCode
          return (
            <option
              key={phoneCode}
              value={phoneCode}
              style={{
                background: isSelected ? 'var(--gray)' : 'var(--white)'
              }}
            >
              {code} {dial_code} {name}
            </option>
          )
        })}
      </PhoneCode>
    </PhoneCodeContainer>
  )
}

export const PhoneCodeContainer = styled.div({
  width: '4.8rem',
  position: 'absolute',
  top: '2.75rem',
  left: '2.5rem'
})

export const PhoneCode = styled.select({
  width: '100%',
  fontSize: '0.875rem',
  fontWeight: 600,
  color: 'var(--light-black)',
  padding: '0.3rem',
  background: 'var(--gray)',
  borderRadius: '0.3125rem',
  border: 0,
  cursor: 'pointer'
})

export default PhoneCodeInput
