import profilePlaceholder from '../../../assets/components/account-profile/profile-placeholder.svg'
import cameraIcon from '../../../assets/components/account-profile/camera.svg'
import styled from '@emotion/styled'
import type { ExtendedProfile, Profile } from '../types'
import type { FormEvent } from 'react'

interface Props {
  newProfile: ExtendedProfile
  updateEdited: () => void
  setNewProfile: React.Dispatch<React.SetStateAction<ExtendedProfile>>
}

const Picture: React.FC<Props> = ({
  newProfile,
  updateEdited,
  setNewProfile
}) => {
  const uploadImage = (event: FormEvent<HTMLInputElement>) => {
    const element = event.target as HTMLInputElement
    const key: keyof Profile = element.name as keyof Profile
    const file = element.files?.[0] as Blob
    const temp = { ...newProfile }
    temp[key] = URL.createObjectURL(file)
    setNewProfile(temp)
    updateEdited()
  }

  return (
    <ProfilePictureContainer>
      <ProfilePictureFrame>
        {newProfile.pictureUrl ? (
          <ProfilePicture src={newProfile.pictureUrl} />
        ) : (
          <ProfilePicture src={profilePlaceholder} />
        )}
      </ProfilePictureFrame>
      <UploadButton htmlFor='pictureUrl'>
        <UploadButtonIcon src={cameraIcon} />
      </UploadButton>
      <input
        id='pictureUrl'
        name='pictureUrl'
        type='file'
        accept='image/*'
        hidden
        onInput={(e) => uploadImage(e)}
      />
    </ProfilePictureContainer>
  )
}

const ProfilePictureContainer = styled.div({
  width: '8.7rem',
  height: '8.7rem',
  position: 'relative',
  marginBottom: '1.5rem'
})

const ProfilePictureFrame = styled.div({
  overflow: 'hidden',
  background: 'var(--gray)',
  display: 'flex',
  justifyContent: 'center',
  alignItems: 'center',
  borderRadius: '50%'
})

const ProfilePicture = styled.img({
  maxHeight: '8.7rem'
})

const UploadButton = styled.label({
  position: 'absolute',
  bottom: '-0.75rem',
  right: '-1rem',
  background: 'var(--white)',
  padding: '0.75rem 0.85rem 0.5rem',
  border: 0,
  borderRadius: '50%',
  boxShadow: '0 0.25rem 0.5rem var(--transparent-green-2)',
  cursor: 'pointer'
})

const UploadButtonIcon = styled.img({
  width: '1.1875rem'
})

export default Picture
