import React, { FormEvent } from 'react'
import * as SC from '../styles'
import type { NewsletterOptions } from '../types'
import { useTranslation } from 'react-i18next'

const emailRegex =
  /^(([^<>()[\]\\.,;:\s@"]+(\.[^<>()[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/

interface Props {
  options: NewsletterOptions
  email: string
  setEmail: (email: string) => void
  invalidEmail: boolean
  setInvalidEmail: (invalidEmail: boolean) => void
  disabledButton: boolean
  setDisabledButton: (disabledButton: boolean) => void
  onSendEmail: (email: string) => void
}

const NewsletterForm: React.FC<Props> = ({
  options: { buttonFont, fieldFont, disableSubmit },
  email,
  setEmail,
  invalidEmail,
  setInvalidEmail,
  disabledButton,
  setDisabledButton,
  onSendEmail
}) => {
  const { t } = useTranslation('newsletter')

  const handleInputEmail = (e: FormEvent) => {
    const input = (e.target as HTMLInputElement).value.trim()
    const invalidInput = !input || !emailRegex.test(input)
    setEmail(input)
    setInvalidEmail(invalidInput)
    setDisabledButton(invalidInput)
  }

  const handleSubmit = () => {
    onSendEmail(email)
  }

  return (
    <>
      <SC.NewsletterForm>
        <SC.Input
          type='text'
          placeholder='contoh@example.com'
          name='email'
          id='email'
          style={{ fontFamily: fieldFont }}
          onInput={handleInputEmail}
        />
        <SC.InputInvalid style={{ display: invalidEmail ? 'block' : 'none' }}>
          {t('invalidText')}
        </SC.InputInvalid>
        <SC.SubmitButtonContainer>
          <SC.SubmitButton
            style={{ fontFamily: buttonFont }}
            disabled={disabledButton || disableSubmit}
            onClick={handleSubmit}
          >
            {t('buttonText')}
          </SC.SubmitButton>
        </SC.SubmitButtonContainer>
      </SC.NewsletterForm>
      <SC.NewsletterRecaptcha>
        This site is protected by reCAPTCHA and the Google{' '}
        <a
          href='https://policies.google.com/privacy'
          rel='noopener noreferrer'
          target='_blank'
        >
          Privacy Policy
        </a>{' '}
        and{' '}
        <a
          href='https://policies.google.com/terms'
          rel='noopener noreferrer'
          target='_blank'
        >
          Terms of Service
        </a>{' '}
        apply.
      </SC.NewsletterRecaptcha>
    </>
  )
}

export default NewsletterForm
