export function errorProfileName(text: string) {
  if (text.length === 0) {
    return {
      id: 'Nama profil pembayaran wajib diisi.',
      en: 'The payment profile name is required.'
    }
  } else {
    return {
      id: '',
      en: ''
    }
  }
}

export function errorCardNumber(text: string) {
  const numberList = text.split('-')
  const textTemp = numberList.join('')
  if (textTemp.length === 0) {
    return {
      id: 'Nomor kartu wajib diisi.',
      en: 'The card number is required.'
    }
  } else if (textTemp.match(/^[0-9]{13,16}$/) === null) {
    return {
      id: 'Format nomor kartu tidak valid.',
      en: 'Invalid card number.'
    }
  } else {
    return {
      id: '',
      en: ''
    }
  }
}

export function errorCardHolder(text: string) {
  if (text.length === 0) {
    return {
      id: 'Nama pemegang kartu wajib diisi.',
      en: 'The card holder is required.'
    }
  } else {
    return {
      id: '',
      en: ''
    }
  }
}

export function errorCardExpiry(text: string) {
  if (text.length === 0) {
    return {
      id: 'Tanggal kadaluarsa wajib diisi.',
      en: 'The expiration date is required.'
    }
  } else if (text.match(/^(0[1-9]|1[0-2])\/?([0-9]{2})$/) === null) {
    return {
      id: 'Tanggal tidak valid.',
      en: 'Invalid expiry date.'
    }
  } else {
    const dateSplit = text.split('/')
    const month = dateSplit[0].toString()
    const year = dateSplit[1].toString()

    const dateNow = new Date()
    let monthNow = (dateNow.getMonth() + 1).toString()
    const yearNow = dateNow.getFullYear().toString().slice(-2)

    if (monthNow.length < 2) monthNow = '0' + monthNow

    if (year <= yearNow) {
      if (month <= monthNow) {
        return {
          id: 'Tanggal kadaluarsa harus tanggal yang akan datang.',
          en: 'The expiry date must be a future date.'
        }
      } else {
        return {
          id: '',
          en: ''
        }
      }
    } else {
      return {
        id: '',
        en: ''
      }
    }
  }
}

export function errorCardCvv(text: string) {
  if (text.length === 0) {
    return {
      id: 'CVV wajib diisi.',
      en: 'The CVV is required.'
    }
  } else if (text.match(/^[0-9]+$/) === null) {
    return {
      id: 'Format CVV tidak valid.',
      en: 'Invalid CVV format.'
    }
  } else {
    return {
      id: '',
      en: ''
    }
  }
}
